@@ -66,6 +66,8 @@ geom_contour_fill <- function(mapping = NULL, data = NULL,
                          breaks = MakeBreaks(),
                          bins = NULL,
                          binwidth = NULL,
+                         proj = NULL,
+                         clip = NULL,
                          kriging = FALSE,
                          global.breaks = TRUE,
                          na.fill = FALSE,
@@ -87,6 +89,8 @@ geom_contour_fill <- function(mapping = NULL, data = NULL,
             na.rm = FALSE,
             na.fill = na.fill,
             kriging = kriging,
+            proj = proj,
+            clip = clip,
             global.breaks = global.breaks,
             ...
         )
