@@ -1,8 +1,6 @@
 
 test_that("GetTopography gets topography", {
     skip_if_offline()
-    skip_on_cran()
-    skip_on_ci()
 
     expect_s3_class(GetTopography(280, 330, 0, -60, resolution = 0.5,
                                   file.dir = "~"), "data.frame")
